#
# spec file for package trytond_stock
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%define pythons python3
%define mypython python3
%define mysitelib %python3_sitelib
%else
%{?sle15_python_module_pythons}
%define mypython %pythons
%define mysitelib %{expand:%%%{mypython}_sitelib}
%endif

%define majorver 6.0
Name:           trytond_stock
Version:        %{majorver}.23
Release:        5.1
Summary:        The "stock" module for the Tryton ERP system
License:        GPL-3.0-only
Group:          Productivity/Office/Management
URL:            http://www.tryton.org/
Source:         http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
Source2:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz.asc
Source3:        https://keybase.io/cedrickrier/pgp_keys.asc?fingerprint=7C5A4360F6DF81ABA91FD54D6FF50AFE03489130#/%{name}.keyring
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-pip
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros

Requires:       trytond
Requires:       trytond_company
Requires:       trytond_currency
Requires:       trytond_party
Requires:       trytond_product

BuildArch:      noarch

%description
The stock module defines fundamentals for all stock management
situations: Locations where product are stored, moves between these
locations, shipments for product arrivals and departures and
inventory to control and update stock levels.

%prep
%setup -q

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{mysitelib}

%files
%defattr(-,root,root)
%{mysitelib}/tryton*

%changelog
* Sat Jan 13 2024 Axel Braun <axel.braun@gmx.de>
- Switch to wheel and %%{?sle15_python_module_pythons}
* Sat Nov 18 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.23 - Bugfix Release
* Thu Oct 19 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Remove %%python3_install prefix and root options, that's included in
  the macro by default.
* Sun Oct  8 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.22 - Bugfix Release
* Thu Sep  7 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.21 - Bugfix Release
* Thu Jun 22 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.20 - Bugfix Release
* Fri Apr  7 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.19 - Bugfix Release
* Fri Nov 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.18 - Bugfix Release
* Tue Oct 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.17 - Bugfix Release
* Wed Sep  7 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.16 - Bugfix Release
* Sun Jul  3 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.15 - Bugfix Release
* Sat Jun  4 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.14 - Bugfix Release
* Mon Apr 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.13 - Bugfix Release
* Wed Mar  2 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.12 - Bugfix Release
* Fri Feb 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.11 - Bugfix Release
* Sat Feb 12 2022 Axel Braun <axel.braun@gmx.de>
- Version bump to Tryton 6.0 series
* Mon Jan  3 2022 Axel Braun <axel.braun@gmx.de>
- Version 5.0.17 - Bugfix Release
* Mon Dec  6 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.16 - Bugfix Release
* Fri Jun 18 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.14 - Bugfix Release
* Mon May 10 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.13 - Bugfix Release
* Sat Feb 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Tue Feb  2 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.12 - Bugfix Release
* Sun Jan 24 2021 Axel Braun <axel.braun@gmx.de>
- Adaption to new python-macros
* Fri Dec  4 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.11 - Bugfix Release
* Thu Jun  4 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.10 - Bugfix Release
* Tue Mar 10 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.9 - Bugfix Release
* Sun Feb  2 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.8 - Bugfix Release
* Thu Nov 21 2019 Axel Braun <axel.braun@gmx.de>
- version 5.0.7 (GNU Health 3.6 series)
* Fri Jul 12 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.7 - Bugfix Release
* Fri May 17 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.6 - Bugfix Release
* Sun Mar 24 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.5 - Bugfix Release
* Tue Nov 13 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.6.4 - Bugfix Release
* Tue Nov 13 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.8 - Bugfix Release
* Thu Apr  5 2018 axel.braun@gmx.de
- Version 4.2.7 - Bugfix Release
* Fri Mar  2 2018 axel.braun@gmx.de
- Version 4.2.6 - Bugfix Release
* Thu Nov  9 2017 axel.braun@gmx.de
- Version 4.2.5 - Bugfix Release
* Wed Oct  4 2017 axel.braun@gmx.de
- Version 4.2.4 - Bugfix Release
* Thu Aug 10 2017 axel.braun@gmx.de
- Version 4.2.3
* Mon Jul  3 2017 axel.braun@gmx.de
- Version 4.2.2
* Fri Mar 10 2017 axel.braun@gmx.de
- Version 4.2.1
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Mon May  2 2016 axel.braun@gmx.de 
- Tryton Release 4.0
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
* Fri Oct 25 2013 axel.braun@gmx.de
- new branch 3.0
* Thu May  2 2013 axel.braun@gmx.de
- initial build
